tlslite.utils

Package tlslite :: Package utils |
[hide private]
[frames] | no frames]

# Package utils

source code

Toolkit for crypto and other stuff.

Submodules | [hide private]
tlslite.utils.aes: Abstract class for AES. tlslite.utils.asn1parser: Class for parsing ASN.1 tlslite.utils.cipherfactory: Factory functions for symmetric cryptography. tlslite.utils.codec: Classes for reading/writing binary data (such as TLS records). tlslite.utils.compat: Miscellaneous functions to mask Python version differences. tlslite.utils.cryptomath: cryptomath module tlslite.utils.datefuncs tlslite.utils.keyfactory: Factory functions for asymmetric cryptography. tlslite.utils.openssl_aes: OpenSSL/M2Crypto AES implementation. tlslite.utils.openssl_rc4: OpenSSL/M2Crypto RC4 implementation. tlslite.utils.openssl_rsakey: OpenSSL/M2Crypto RSA implementation. tlslite.utils.openssl_tripledes: OpenSSL/M2Crypto 3DES implementation. tlslite.utils.pem tlslite.utils.pycrypto_aes: PyCrypto AES implementation. tlslite.utils.pycrypto_rc4: PyCrypto RC4 implementation. tlslite.utils.pycrypto_rsakey: PyCrypto RSA implementation. tlslite.utils.pycrypto_tripledes: PyCrypto 3DES implementation. tlslite.utils.python_aes: Pure-Python AES implementation. tlslite.utils.python_rc4: Pure-Python RC4 implementation. tlslite.utils.python_rsakey: Pure-Python RSA implementation. tlslite.utils.rc4: Abstract class for RC4. tlslite.utils.rijndael: A pure python (slow) implementation of rijndael with a decent interface tlslite.utils.rsakey: Abstract class for RSA. tlslite.utils.tackwrapper tlslite.utils.tripledes: Abstract class for 3DES.

Variables | [hide private]
| __package__ = `None`